@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 from mootdx.consts import HQ_HOSTS, EX_HOSTS, GP_HOSTS
 
-__version__ = "0.6.6"
-__author__ = "bopo.wang"
+__version__ = "0.6.7"
+__author__ = "bopo.wang<ibopo@126.com>"
 
 CONFIG = {
     'SERVER': {
