@@ -24,10 +24,10 @@ class Affair(object):
         logger.debug(filepath)
 
         if os.path.exists(filepath):
-            result = financial.FinancialReader().to_data(filepath)
-            return result
+            return financial.FinancialReader().to_data(filepath)
 
         logger.error('文件不存在：{}'.format(filename))
+        
         return None
 
     @staticmethod
@@ -63,11 +63,8 @@ class Affair(object):
             logger.info('下载文件 {}.'.format(filename))
             downfile = os.path.join(downdir, filename)
 
-            with TqdmUpTo(unit='B', unit_scale=True, miniters=1,
-                          ascii=True) as t:
-                crawler.fetch_and_parse(reporthook=t.update_to,
-                                        filename=filename,
-                                        downdir=downfile)
+            with TqdmUpTo(unit='B', unit_scale=True, miniters=1, ascii=True) as t:
+                crawler.fetch_and_parse(reporthook=t.update_to, filename=filename, downdir=downfile)
 
             return True
 
@@ -82,9 +79,6 @@ class Affair(object):
                     logger.warning('[!] 文件已经存在: {} 跳过.'.format(x['filename']))
                     continue
 
-            with TqdmUpTo(unit='b', unit_scale=True, miniters=1,
-                          ascii=True) as t:
+            with TqdmUpTo(unit='b', unit_scale=True, miniters=1, ascii=True) as t:
                 logger.warning('\r[+] 准备下载文件 {}.'.format(x['filename']))
-                crawler.fetch_and_parse(reporthook=t.update_to,
-                                        filename=x['filename'],
-                                        downdir=downfile)
+                crawler.fetch_and_parse(reporthook=t.update_to, filename=x['filename'], downdir=downfile)
