@@ -8,15 +8,16 @@ import tempfile
 from struct import calcsize, unpack
 
 import pandas as pd
-from mootdx.consts import GP_HOSTS
 
+from mootdx.consts import GP_HOSTS
 from .base import BaseFinancial, BaseReader
+from mootdx import config
+from mootdx.config import settings
 
 logger = logging.getLogger(__name__)
 
 
 class FinancialReader(BaseReader):
-
     def to_data(self, filename, **kwargs):
         """
         读取历史财务数据文件，并返回pandas结果 ， 类似gpcw20171231.zip格式，具体字段含义参考
@@ -52,11 +53,17 @@ class FinancialList(BaseFinancial):
         :param kwargs:
         :return:
         '''
-        # return "https://gitee.com/yutiansut/QADATA/raw/master/financial/content.txt"
+        return "https://gitee.com/yutiansut/QADATA/raw/master/financial/content.txt"
         # return 'http://down.tdx.com.cn:8001/fin/gpcw.txt'
-        return 'http://data.yutiansut.com/content.txt'
+        # return 'http://data.yutiansut.com/content.txt'
 
-    def content(self, reporthook=None, downdir=None, proxies=None, chunksize=1024 * 50, *args, **kwargs):
+    def content(self,
+                reporthook=None,
+                downdir=None,
+                proxies=None,
+                chunksize=1024 * 50,
+                *args,
+                **kwargs):
         '''
         解析财务文件
 
@@ -70,10 +77,16 @@ class FinancialList(BaseFinancial):
         '''
         from pytdx.hq import TdxHq_API
 
-        api = TdxHq_API()
+        api = TdxHq_API(**kwargs)
         api.need_setup = False
 
-        with api.connect(ip=GP_HOSTS[0]):
+        try:
+            default = settings.get('SERVER').get('GP')[0][1:]
+            bestip = config.get('BESTIP').get('GP', default)
+        except ValueError:
+            bestip = ("106.14.95.149", 7727)
+
+        with api.connect(*bestip):
             content = api.get_report_file_by_size("tdxfin/gpcw.txt")
 
             if downdir is None:
@@ -102,7 +115,12 @@ class FinancialList(BaseFinancial):
             return {'filename': l[0], 'hash': l[1], 'filesize': int(l[2])}
 
         if content:
-            result = [list_to_dict(l) for l in [line.strip().split(",") for line in content.strip().split('\n')]]
+            result = [
+                list_to_dict(l) for l in [
+                    line.strip().split(",")
+                    for line in content.strip().split('\n')
+                ]
+            ]
             return result
 
         return None
@@ -127,12 +145,18 @@ class Financial(BaseFinancial):
         if not filename:
             raise Exception("Param filename is not set")
 
-        logger.debug("http://down.tdx.com.cn:8001/fin/{}".format(filename))
+        # logger.debug(f"http://down.tdx.com.cn:8001/fin/{filename}")
 
-        return "http://data.yutiansut.com/{}".format(filename)
-        # return "http://down.tdx.com.cn:8001/fin/{}".format(filename)
+        # return "http://data.yutiansut.com/{}".format(filename)
+        return "http://down.tdx.com.cn:8001/fin/{}".format(filename)
 
-    def content(self, reporthook=None, downdir=None, proxies=None, chunksize=1024 * 50, *args, **kwargs):
+    def content(self,
+                reporthook=None,
+                downdir=None,
+                proxies=None,
+                chunksize=1024 * 50,
+                *args,
+                **kwargs):
         '''
         解析财务文件
 
@@ -156,14 +180,18 @@ class Financial(BaseFinancial):
         api.need_setup = False
 
         try:
-            config = json.loads('config.josn')
-            bestip = config.get('hosts').get('gp')
-        except ValueError as e:
-            raise e
+            default = settings.get('SERVER').get('GP')[0][1:]
+            bestip = config.get('BESTIP').get('GP', default)
+        except ValueError:
+            bestip = ("106.14.95.149", 7727)
 
         with api.connect(*bestip):
-            content = api.get_report_file_by_size("tdxfin/" + filename, filesize=filesize, reporthook=reporthook)
-            download_file = open(downdir, 'wb') if downdir else tempfile.NamedTemporaryFile(delete=True)
+            content = api.get_report_file_by_size(f"tdxfin/{filename}",
+                                                  filesize=filesize,
+                                                  reporthook=reporthook)
+            download_file = open(
+                downdir, 'wb') if downdir else tempfile.NamedTemporaryFile(
+                    delete=True)
             download_file.write(content)
             download_file.seek(0)
 
@@ -240,6 +268,11 @@ class Financial(BaseFinancial):
         return results
 
     def to_df(self, data):
+        '''
+        转换数据为 pandas DataFrame 格式
+        :param data: 要转换的数据
+        :return: DataFrame
+        '''
         if len(data) == 0:
             return None
 
