@@ -59,10 +59,11 @@ def Server(index=None, limit=5, console=False, verbose=False):
             proxy['time'] = (time.perf_counter() - start) * 1000
 
             server.append(proxy)
-            logger.info(
-                "{addr}:{port} 验证通过，响应时间：{time:5.2f} ms.".format(**proxy))
+            logger.info("{}:{} 验证通过，响应时间：{:5.2f} ms.".format(
+                proxy.get('addr'), proxy.get('port'), proxy.get('time')))
         except Exception:
-            logger.warning("{addr},{port} 验证失败.".format(**proxy))
+            logger.warning("{},{} 验证失败.".format(proxy.get('addr'),
+                                                proxy.get('port')))
 
     # 结果按响应时间从小到大排序
     server.sort(key=lambda item: item['time'])
